@@ -475,7 +475,14 @@ static int liqbookreader_layout(liqcell *self, liqcelleventargs *args,void *cont
 		
 		//=================================================== now, open the font
 		
-		liqfont *font = liqfont_newfromfilettf("/usr/share/fonts/nokia/nosnb.ttf", (edfontsize), 0);
+		liqfont *font;
+		
+		if(strcmp(bookfilename,"/usr/share/liqbase/libliqbase/media/liqbase.info.txt") == 0)
+			font = liqfont_newfromfilettf("liquid@gmail.com", (edfontsize), 0);
+		else
+		
+			font = liqfont_newfromfilettf("/usr/share/fonts/nokia/nosnb.ttf", (edfontsize), 0);
+
 
 
 		if(!font)
